#
# spec file for package python-uncompyle6
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-uncompyle6
Version:        3.7.4
Release:        bp155.2.10
Summary:        Python cross-version byte-code decompiler
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/rocky/python-uncompyle6/
Source:         https://files.pythonhosted.org/packages/source/u/uncompyle6/uncompyle6-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-hypothesis >= 2.0.0
Requires:       python-setuptools
Requires:       python-spark_parser >= 1.8.9
Requires:       python-xdis >= 5.0.4
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module hypothesis >= 2.0.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module spark_parser >= 1.8.9}
BuildRequires:  %{python_module xdis >= 5.0.4}
# /SECTION
%python_subpackages

%description
A native Python cross-version decompiler and fragment decompiler.
The successor to decompyle, uncompyle, and uncompyle2.

%prep
%setup -q -n uncompyle6-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pydisassemble
%python_clone -a %{buildroot}%{_bindir}/uncompyle6
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest pytest

%post
%python_install_alternative pydisassemble
%python_install_alternative uncompyle6

%postun
%python_uninstall_alternative pydisassemble
%python_uninstall_alternative uncompyle6

%files %{python_files}
%license COPYING
%doc ChangeLog README README.rst
%python_alternative %{_bindir}/uncompyle6
%python_alternative %{_bindir}/pydisassemble
%{python_sitelib}/*

%changelog
* Thu Dec 31 2020 olaf@aepfle.de
- update to 3.7.4
  * Fragment parsing was borked. This means deparsing in trepan2/trepan3k was broken
  * 3.7+: narrow precedence for call tatement
  * del_stmt -> delete to better match Python AST
  * 3.8+ Add another forelsestmt (found only in a loop)
  * 3.8+ Add precedence on walrus operator
  * More files blackened
  * bump min xdis version
  * __doc__ = DocDescr() from test_descr.py was getting confused as a docstring.
  * detect 2.7 exchandler range better
  * Add reduce check for 2.7 augmented assign
  * Add VERSION in a pydoc-friendly way
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.7.2
  * Use newer xdis
  * Docstrings (again) which were broken again on earlier Python
  * Fix 2.6 and 2.7 decompilation bug in handling "list if" comprehensions
  * Handle 3.7+ "else" branch removal adAs seen in `_cmp()` of `python3.8/distutils/version.py` with optimization `-O2`
  * 3.6+ "with" and "with .. as" grammar improvements
  * ast-check for "for" loop was missing some grammar rules
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.7.0
  * The main impetus for this release is to pull in the recent changes from xdis. We simplify imports using xdis 4.6.0.
  * There were some bugfixes to Python 3.4-3.8. See the ChangeLog for details
* Mon May 18 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Apr 17 2020 pgajdos@suse.com
- version update to 3.6.5
  * Handle nested async for in for... and better async comprehension detection via xdis. Still more work is needed.
  * include token number in listings when -g and there is a parser error
  * remove unneeded Makefiles now that remake 4.3+1.5dbg is a thing that has -c
  * Bug in finding annotations in functions with docstrings
  * Fix bug found by 2.4 sre_parse.py testing
  * Fix transform module's ifelseif bugs
  * Fix bug in 3.0 name module detection
  * Fix docstring detection
* Tue Mar 10 2020 pgajdos@suse.com
- version update to 3.6.4
  * The main focus in this release was fix some of the more glaring
    problems creapt in from the last release due to that refactor.
  * See ChangeLog for details.
* Fri Feb  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.6.3
  * Fix fragment bugs
  * Preliminary support for decompiling Python 1.0, 1.1, 1.2, and 1.6
  * Pypy 3.3, 3.5, 3.6, and 3.6.9 support
  * Improve 3.0 decompilation
  * Fix unmarshal incompletness detected in Pypy 3.6
  * more accurate decompilation especially for 3.7 and 3.8.
  * runing in 3.9-dev is tolerated
  * Numerous bugs around handling lambda with keyword-only fixed.
  * binary_expr and unary_expr have been renamed to bin_op and unary_op
  * TL;DR, but nothing important
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.4.0:
  * The main change is to add a tree-transformation phase
  * Various bugfixes
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.3.5:
  * No upstream changelog
* Fri Jun 28 2019 Andreas Färber <afaerber@suse.de>
- Initial (v3.3.4)
